@@ -1,9 +1,9 @@
 #!/usr/bin/perl
 
-# Po4a::Dia.pm 
-# 
+# Po4a::Dia.pm
+#
 # extract and translate translatable strings from Dia diagrams.
-# 
+#
 # This code extracts plain text from string tags on uncompressed Dia
 # diagrams.
 #
@@ -26,13 +26,15 @@
 #
 ########################################################################
 
+=encoding UTF-8
+
 =head1 NAME
 
-Locale::Po4a::Dia - Convert uncompressed Dia diagrams from/to PO files
+Locale::Po4a::Dia - convert uncompressed Dia diagrams from/to PO files
 
 =head1 DESCRIPTION
 
-The po4a (po for anything) project goal is to ease translations (and more
+The po4a (PO for anything) project goal is to ease translations (and more
 interestingly, the maintenance of translations) using gettext tools on
 areas where they were not expected like documentation.
 
@@ -60,7 +62,7 @@ tag), not interesting for translation.
 
 =head1 SEE ALSO
 
-L<po4a(7)|po4a.7>, L<Locale::Po4a::TransTractor(3pm)>, L<Locale::Po4a::Xml(3pm)>.
+L<Locale::Po4a::TransTractor(3pm)>, L<Locale::Po4a::Xml(3pm)>, L<po4a(7)|po4a.7>
 
 =head1 AUTHORS
 
@@ -87,25 +89,25 @@ use vars qw(@ISA);
 @ISA = qw(Locale::Po4a::Xml);
 
 sub initialize {
-	my $self = shift;
-	my %options = @_;
+    my $self = shift;
+    my %options = @_;
 
-	$self->SUPER::initialize(%options);
-	$self->{options}{'tagsonly'}=1;
-	$self->{options}{'nostrip'}=1;
-	$self->{options}{'_default_translated'}.=' <dia:string>';
-	$self->treat_options;
+    $self->SUPER::initialize(%options);
+    $self->{options}{'nostrip'}=1;
+    $self->{options}{'_default_translated'}.=' <dia:string>';
+    $self->treat_options;
 }
 
 sub found_string {
-	my ($self,$text,$ref,$options)=@_;
+    my ($self,$text,$ref,$options)=@_;
+    return $text if $text =~ m/^\s*$/s;
 
-	#We skip the paper type string
-	if ( $self->get_path() !~ /<dia:diagramdata>/ ) {
-		$text =~ /^#(.*)#$/s;
-		$text = "#".$self->translate($1,$ref,"String",
-			'wrap'=>$self->{options}{'wrap'})."#";
-	}
+    #We skip the paper type string
+    if ( $self->get_path() !~ /<dia:diagramdata>/ ) {
+        $text =~ /^#(.*)#$/s;
+        $text = "#".$self->translate($1,$ref,"String",
+            'wrap'=>$self->{options}{'wrap'})."#";
+    }
 
-	return $text;
+    return $text;
 }
