@@ -29,50 +29,47 @@ sub initialize {}
 
 
 sub parse {
-	my $self=shift;
-	my ($line,$ref);
-	my $par;
+    my $self=shift;
+    my ($line,$ref);
+    my $par;
 
-	LINE:
-	($line,$ref)=$self->shiftline();
+    LINE:
+    ($line,$ref)=$self->shiftline();
 
-	while (defined($line)) {
-		chomp($line);
-		print STDERR  "begin\n" if $debug;
+    while (defined($line)) {
+        chomp($line);
+        print STDERR  "begin\n" if $debug;
 
-		if ($line =~ /\"/) {
-			print STDERR  "Start of line containing \".\n" if $debug;
-			# Text before the first quote
-			$line =~ m/(^[^"\r\n]*")/;
-			my $pre_text = $1;
-			print STDERR  "  PreText=".$pre_text."\n" if $debug;
-			# The text for translation
-			$line =~ m/("[^\r\n]*")/;
-			my $quoted_text = $1;
-			print STDERR  "  QuotedText=".$quoted_text."\n" if $debug;
-			# Text after last quote
-			$line =~ m/("[^"\n]*$)/;
-			my $post_text = $1;
-			print STDERR  "  PostText=".$post_text."\n" if $debug;
-			# Remove starting and ending quotes from the translation text, if any
-			$quoted_text =~ s/^"//g;
-			$quoted_text =~ s/"$//g;
-			# Translate the string it
-			$par = $self->translate($quoted_text, $ref);
-			# Escape the \n characters
-			$par =~ s/\n/\\n/g;
-			# Now push the result
-			$self->pushline($pre_text.$par.$post_text."\n");
-			print STDERR  "End of line containing \".\n" if $debug;
-		}
-		else
-		{
-			print STDERR "Other stuff\n" if $debug;
-			$self->pushline("$line\n");
-		}
-		# Reinit the loop
-		($line,$ref)=$self->shiftline();
-	}
+        if ($line =~ /\"/) {
+            print STDERR  "Start of line containing \".\n" if $debug;
+            # Text before the first quote
+            $line =~ m/(^[^"\r\n]*)"/;
+            my $pre_text = $1;
+            print STDERR  "  PreText=".$pre_text."\n" if $debug;
+            # The text for translation
+            $line =~ m/"([^\r\n]*)"/;
+            my $quoted_text = $1;
+            print STDERR  "  QuotedText=".$quoted_text."\n" if $debug;
+            # Text after last quote
+            $line =~ m/"([^"\n]*$)/;
+            my $post_text = $1;
+            print STDERR  "  PostText=".$post_text."\n" if $debug;
+            # Translate the string it
+            $par = $self->translate($quoted_text, $ref, $pre_text);
+            # Escape the \n characters
+            $par =~ s/\n/\\n/g;
+            # Now push the result
+            $self->pushline($pre_text.'"'.$par.'"'.$post_text."\n");
+            print STDERR  "End of line containing \".\n" if $debug;
+        }
+        else
+        {
+            print STDERR "Other stuff\n" if $debug;
+            $self->pushline("$line\n");
+        }
+        # Reinit the loop
+        ($line,$ref)=$self->shiftline();
+    }
 }
 
 ##############################################################################
@@ -86,7 +83,7 @@ __END__
 
 =head1 NAME
 
-Locale::Po4a::Ini - Convert ini files from/to PO files
+Locale::Po4a::Ini - convert INI files from/to PO files
 
 =head1 DESCRIPTION
 
@@ -102,7 +99,7 @@ NOTE: If the text is not quoted, it will be ignored.
 
 =head1 SEE ALSO
 
-L<po4a(7)|po4a.7>, L<Locale::Po4a::TransTractor(3pm)>.
+L<Locale::Po4a::TransTractor(3pm)>, L<po4a(7)|po4a.7>
 
 =head1 AUTHORS
 
