@@ -157,7 +157,7 @@ This option is only useful for mdoc pages.
 
 It selects a stricter support of the mdoc format by telling po4a not to
 translate the 'NAME' section.
-mdoc pages whose 'NAME' section is translated won't generate any header of
+mdoc pages whose 'NAME' section is translated won't generate any header or
 footer.
 
 According to the groff_mdoc page, the NAME, SYNOPSIS and DESCRIPTION
@@ -175,7 +175,7 @@ This mdoc issue can also be solved with an addendum like this one:
 
 The following options permit to specify the behavior of a new macro
 (defined with a .de request), or of a macro not supported by po4a.
-They take in argument a coma separated list of macros.
+They take as argument a comma-separated list of macros.
 For example:
 
  -o noarg=FO,OB,AR -o translate_joined=BA,ZQ,UX
@@ -207,7 +207,7 @@ translation, except that each one will be translated separately.
 
 =item B<no_wrap>
 
-This option takes in argument a list of coma-separated couples
+This option takes as argument a list of comma-separated couples
 I<begin>:I<end>, where I<begin> and I<end> are commands that delimit
 the begin and end of a section that should not be rewrapped.
 
@@ -220,7 +220,7 @@ These macros (and their arguments) wont be translated.
 
 =item B<inline>
 
-This option specifies a list of coma-separated macros that must
+This option specifies a list of comma-separated macros that must
 not split the current paragraph. The string to translate will then contain
 I<foo E<lt>.bar baz quxE<gt> quux>, where I<bar> is the command that
 should be inlined, and I<baz qux> its arguments.
@@ -229,8 +229,9 @@ should be inlined, and I<baz qux> its arguments.
 
 This option indicates how po4a should behave when an unknown macro is found.
 By default, po4a fails with a warning.
-It can take the following values: I<failed> (the default value),
-I<untranslated>, I<noarg>, I<translate_joined>, I<translate_each>.
+It can take the following values: B<failed> (the default value),
+B<untranslated>, B<noarg>, B<translate_joined>, or B<translate_each> (see above
+for an explanation of these values).
 
 =back
 
@@ -270,7 +271,7 @@ my box are inaccessible to po4a::man.
  .BE              ..br            .Bu             .BUGS           .BY
  .ce              .dbmmanage      .do                             .En
  .EP              .EX             .Fi             .hw             .i
- .Id              .l              .LO             .mf             
+ .Id              .l              .LO             .mf
  .N               .na             .NF             .nh             .nl
  .Nm              .ns             .NXR            .OPTIONS        .PB
  .pp              .PR             .PRE            .PU             .REq
@@ -278,7 +279,7 @@ my box are inaccessible to po4a::man.
  .splitfont       .Sx             .T              .TF             .The
  .TT              .UC             .ul             .Vb             .zZ
 
-=head2 Hiding text to po4a
+=head2 Hiding text from po4a
 
 Sometimes, the author knows that some parts are not translatable, and
 should not be extracted by po4a. For example, an option may accept an
@@ -372,8 +373,9 @@ the processed pages).
 
 =head1 SEE ALSO
 
-L<po4a(7)|po4a.7>, L<Locale::Po4a::TransTractor(3pm)>,
-L<Locale::Po4a::Pod(3pm)>.
+L<Locale::Po4a::Pod(3pm)>,
+L<Locale::Po4a::TransTractor(3pm)>,
+L<po4a(7)|po4a.7>
 
 =head1 AUTHORS
 
@@ -665,7 +667,7 @@ NEW_LINE:
                         "This file was generated with %s. ".
                         "You should translate the source file, but continuing anyway."
                         ),"latex2man");
-                } elsif ($c =~ /Generated by db2man.xsl/)  { 
+                } elsif ($c =~ /Generated by db2man.xsl/)  {
                     warn wrap_ref_mod($ref, "po4a::man", dgettext("po4a","This file was generated with db2man.xsl. Translate the source file with the xml module of po4a."));
                     exit 254;
                 } elsif ($c =~ /generated automatically by mtex2man/)  {
@@ -684,8 +686,8 @@ NEW_LINE:
 
         if ($line =~ m/^[.']*$/) {
             if ($c !~ m/^\s+$/) {
-                # This commentted line may be comment for the next paragraph
-                push @next_comments, $c;
+                # This commented line may be comment for the next paragraph
+                push @next_comments, [$line ? substr($line,0,1) : '.', $c];
             }
             if ($line =~ m/^[.']+$/) {
                 # those lines are ignored
@@ -697,7 +699,7 @@ NEW_LINE:
                 goto NEW_LINE;
             }
         } else {
-            push @comments, $c;
+            push @comments, ['.', $c];
         }
     } else {
         # finally, we did not reach the end of the paragraph.  The comments
@@ -786,11 +788,11 @@ NEW_LINE:
         # .IR italic/roman
         # .RB roman/bold
         # .RI roman/italic
-        if ($macro eq 'BI' || $macro eq 'BR' || $macro eq 'IB' || 
+        if ($macro eq 'BI' || $macro eq 'BR' || $macro eq 'IB' ||
             $macro eq 'IR' || $macro eq 'RB' || $macro eq 'RI'   ) {
             # num of seen args, first letter of macro name, second one
             my ($i,$a,$b)=(0,substr($macro,0,1),substr($macro,1));
-            $line = join("", map { $i++ % 2 ? 
+            $line = join("", map { $i++ % 2 ?
                                     "\\f$b$_" :
                                     "\\f$a$_"
                                  } @args)."\\fR\n";
@@ -831,7 +833,7 @@ sub pushline {
         # add comments
         foreach my $c (@comments) {
             # comments are pushed (maybe at the wrong place).
-            $self->SUPER::pushline($self->r(".\\\"$c\n"));
+            $self->SUPER::pushline($self->r("$$c[0]\\\"$$c[1]\n"));
         }
         @comments = ();
     }
@@ -843,9 +845,9 @@ sub pushline {
 # is overloaded
 sub unshiftline {
     die wrap_mod("po4a::man", dgettext("po4a",
-	"The unshiftline is not supported for the man module. ".
-	"Please send a bug report with the groff page that generated ".
-	"this error."));
+        "The unshiftline is not supported for the man module. ".
+        "Please send a bug report with the groff page that generated ".
+        "this error."));
 }
 
 ###############################################
@@ -853,54 +855,54 @@ sub unshiftline {
 ###############################################
 sub pushmacro {
     my $self=shift;
-    if (scalar @_) { 
-	# Do quote the arguments containing spaces, as it should.
-	
-	#  but do not do so if they already contain quotes and escaped spaces
-	# For example, cdrdao(1) uses:
-	# .IP CATALOG\ "ddddddddddddd" (Here, the quote have to be displayed)
-	# Adding extra quotes as in:
-	# .IP "CATALOG\ "ddddddddddddd""
-	# results in two args: 'CATALOG\ ' and 'ddddddddddddd""'
-	$self->pushline(join(" ",map {
-		# Replace double quotes by \(dq (double quotes could be
-		# taken as an argument delimiter).
-		# Only quotes not preceded by \ are taken into account
-		# (\" introduces a comment).
-		s/(?<!\\)"/\\\(dq/g if (defined $_);
+    if (scalar @_) {
+        # Do quote the arguments containing spaces, as it should.
 
-		defined $_ ? (
-			length($_)?
-			    (m/([^\\] |^ )/ ? "\"$_\"" : "$_")
-			    # Quote arguments that contain a space.
-			    # (not needed for non breaknig spaces, i.e.
-			    # spaces preceded by '\')
-			    :'""' # empty argument
-		) : '' # no argument
-	    } @_)."\n");
+        #  but do not do so if they already contain quotes and escaped spaces
+        # For example, cdrdao(1) uses:
+        # .IP CATALOG\ "ddddddddddddd" (Here, the quote have to be displayed)
+        # Adding extra quotes as in:
+        # .IP "CATALOG\ "ddddddddddddd""
+        # results in two args: 'CATALOG\ ' and 'ddddddddddddd""'
+        $self->pushline(join(" ",map {
+                # Replace double quotes by \(dq (double quotes could be
+                # taken as an argument delimiter).
+                # Only quotes not preceded by \ are taken into account
+                # (\" introduces a comment).
+                s/(?<!\\)"/\\\(dq/g if (defined $_);
+
+                defined $_ ? (
+                        length($_)?
+                            (m/([^\\] |^ )/ ? "\"$_\"" : "$_")
+                            # Quote arguments that contain a space.
+                            # (not needed for non breaknig spaces, i.e.
+                            # spaces preceded by '\')
+                            :'""' # empty argument
+                ) : '' # no argument
+            } @_)."\n");
     } else {
-	$self->pushline("\n");
+        $self->pushline("\n");
     }
 }
 sub this_macro_needs_args {
     my ($macroname,$ref,$args)=@_;
     unless (length($args)) {
-	die wrap_ref_mod($ref, "po4a::man", dgettext("po4a",
-		"macro %s called without arguments. ".
-		"Even if placing the macro arguments on the next line is authorized ".
-		"by man(7), handling this would make the po4a parser too complicate. ".
-		"Please simply put the macro args on the same line."
-		), $macroname);
+        die wrap_ref_mod($ref, "po4a::man", dgettext("po4a",
+                "macro %s called without arguments. ".
+                "Even if placing the macro arguments on the next line is authorized ".
+                "by man(7), handling this would make the po4a parser too complicate. ".
+                "Please simply put the macro args on the same line."
+                ), $macroname);
     }
 }
 
 sub pre_trans {
     my ($self,$str,$ref,$type)=@_;
-    # Preformatting, so that translators don't see 
+    # Preformatting, so that translators don't see
     # strange chars
     my $origstr=$str;
     print STDERR "pre_trans($str)="
-	if ($debug{'pretrans'});
+        if ($debug{'pretrans'});
 
     # Do as few treatments as possible with the .de, .ie and .if sections
     if (defined $self->{type} && $self->{type} =~ m/^(ie|if|de)$/) {
@@ -915,7 +917,7 @@ sub pre_trans {
                    (?![ \t]*[.'])/$1$2/sgx;# not followed by a command (.')
     }
     die wrap_ref_mod($ref, "po4a::man", dgettext("po4a","Escape sequence \\c encountered. This is not completely handled yet."))
-	if ($str =~ /\\c/);
+        if ($str =~ /\\c/);
 
     $str =~ s/>/E<gt>/sg;
     $str =~ s/</E<lt>/sg;
@@ -973,7 +975,7 @@ sub pre_trans {
     $str =~ s/\\\*\(rq/''/sg;
     $str =~ s/\\\(dq/"/sg;
     }
-    
+
     # non-breaking spaces
     # some non-breaking spaces may have been added during the parsing
     $str =~ s/\Q$nbs/\\ /sg;
@@ -987,8 +989,8 @@ sub post_trans {
     my $transstr=$str;
 
     print STDERR "post_trans($str)="
-	if ($debug{'postrans'});
-    
+        if ($debug{'postrans'});
+
     # Do as few treatments as possible with the .de, .ie and .if sections
     if (defined $self->{type} && $self->{type} =~ m/^(ie|if|de)$/) {
         return $str;
@@ -1067,24 +1069,24 @@ sub post_trans {
     # Make sure we compute internal sequences right.
     # think about: B<AZE E<lt> EZA E<gt>>
     while ($str =~ m/^(.*)(CW|[RBI])<(.*)$/s) {
-	my ($done,$rest)=($1."\\f$2",$3);
-	$done =~ s/CW$/\(CW/;
-	my $lvl=1;
-	while (length $rest && $lvl > 0) {
-	    my $first=substr($rest,0,1);
-	    if ($first eq '<') {
-		$lvl++;
-	    } elsif ($first eq '>') {
-		$lvl--;
-	    } 
-	    $done .= $first  if ($lvl > 0);
-	    $rest=substr($rest,1);
-	}
-	die wrap_ref_mod($ref||$self->{ref}, "po4a::man", dgettext("po4a","Unbalanced '<' and '>' in font modifier. Faulty message: %s"),$str)
-	    if ($lvl > 0);
-	# Return to the regular font
-	$done .= "\\fP$rest";
-	$str=$done;
+        my ($done,$rest)=($1."\\f$2",$3);
+        $done =~ s/CW$/\(CW/;
+        my $lvl=1;
+        while (length $rest && $lvl > 0) {
+            my $first=substr($rest,0,1);
+            if ($first eq '<') {
+                $lvl++;
+            } elsif ($first eq '>') {
+                $lvl--;
+            }
+            $done .= $first  if ($lvl > 0);
+            $rest=substr($rest,1);
+        }
+        die wrap_ref_mod($ref||$self->{ref}, "po4a::man", dgettext("po4a","Unbalanced '<' and '>' in font modifier. Faulty message: %s"),$str)
+            if ($lvl > 0);
+        # Return to the regular font
+        $done .= "\\fP$rest";
+        $str=$done;
     }
 
     while ($str =~ m/^(.*?)E<([.'][\t ]*.*?(?<!E<[gl]t))>(.*)$/s) {
@@ -1125,7 +1127,7 @@ sub post_trans {
     $str =~ s/E<lt>/</mg;
     # Don't do that, because we'll go into trouble if previous line was .TP
     # $str =~ s/^\\f([BI])(.*?)\\f[RP]$/\.$1 $2/mg;
-    
+
     unless ($mdoc_mode) {
         my $tmp = "";
         while ($str =~ m/^(.*?)(``|'')(.*)$/s) {
@@ -1165,7 +1167,7 @@ sub translate {
     my ($self,$str,$ref,$type) = (shift, shift, shift,shift);
     my (%options)=@_;
     my $origstr=$str;
-    
+
     return $str unless (defined $str) && length($str);
     return $str if ($str eq "\n");
     # Do not translate the strings that only consist of fonts, spaces and
@@ -1186,26 +1188,26 @@ sub translate {
     }
 
     $str=pre_trans($self,$str,$ref||$self->{ref},$type);
-    $options{'comment'} .= join('\n', @comments);
+    $options{'comment'} .= join('\n', map{ $$_[1] } @comments);
     # Translate this
     $str = $self->SUPER::translate($str,
-				   $ref||$self->{ref},
-				   $type || $self->{type},
-				   %options);
+                                   $ref||$self->{ref},
+                                   $type || $self->{type},
+                                   %options);
     if ($options{'wrap'}) {
-	my (@paragraph);
-	@paragraph=split (/\n/,$str);
-	if (defined ($paragraph[0]) && $paragraph[0] eq '') {
-	    shift @paragraph;
-	}
-	$str = join("\n",@paragraph)."\n";
+        my (@paragraph);
+        @paragraph=split (/\n/,$str);
+        if (defined ($paragraph[0]) && $paragraph[0] eq '') {
+            shift @paragraph;
+        }
+        $str = join("\n",@paragraph)."\n";
     }
     $str=post_trans($self,$str,$ref||$self->{ref},$type, $options{'wrap'});
     return $str;
 }
 
 # shortcut
-sub t { 
+sub t {
     return $_[0]->translate($_[1]);
 }
 
@@ -1229,14 +1231,14 @@ sub do_paragraph {
 
     # Following needed because of 'ft' (at least, see ft macro below)
     unless ($paragraph =~ m/\n$/s) {
-	my @paragraph = split(/\n/,$paragraph);
+        my @paragraph = split(/\n/,$paragraph);
 
-	$paragraph .= "\n"
-	    unless scalar (@paragraph) == 1;
+        $paragraph .= "\n"
+            unless scalar (@paragraph) == 1;
     }
 
     $self->pushline( $self->translate($paragraph,$self->{ref},"Plain text",
-				      "wrap" => ($wrapped_mode eq 'YES') ) );
+                                      "wrap" => ($wrapped_mode eq 'YES') ) );
 }
 
 #############################
@@ -1246,11 +1248,11 @@ sub parse{
     my $self = shift;
     my ($line,$ref);
     my ($paragraph)=""; # Buffer where we put the paragraph while building
-    my $wrapped_mode='YES'; # Should we wrap the paragraph? Three possible values: 
+    my $wrapped_mode='YES'; # Should we wrap the paragraph? Three possible values:
                             # YES: do wrap
                             # NO: don't wrap because this paragraph contains indented lines
                             #     this status disapear after the end of the paragraph
-                            # MACRONO: don't wrap because we saw the nf macro. It stays so 
+                            # MACRONO: don't wrap because we saw the nf macro. It stays so
                             #          until the next fi macro.
 
 
@@ -1261,141 +1263,141 @@ sub parse{
   LINE:
     undef $self->{type};
     ($line,$ref)=$self->shiftline();
-    
+
     while (defined($line)) {
-#	print STDERR "line=$line;ref=$ref";
-	chomp($line);
-	$self->{ref}="$ref";
-#	print STDERR "LINE=$line<<\n";
+#        print STDERR "line=$line;ref=$ref";
+        chomp($line);
+        $self->{ref}="$ref";
+#        print STDERR "LINE=$line<<\n";
 
 
-	if ($line =~ /^[.']/) {
-	    die wrap_mod("po4a::man", dgettext("po4a", "Unparsable line: %s"), $line)
-		unless ($line =~ /^([.']+\\*?)(\\["#])(.*)/ ||
-			$line =~ /^([.'])(\S*)(.*)/);
-	    my $arg1=$1;
-	    $arg1 .= $2;
-	    my $macro=$2;
-	    my $arguments=$3;
+        if ($line =~ /^[.']/) {
+            die wrap_mod("po4a::man", dgettext("po4a", "Unparsable line: %s"), $line)
+                unless ($line =~ /^([.']+\\*?)(\\["#])(.*)/ ||
+                        $line =~ /^([.'])(\S*)(.*)/);
+            my $arg1=$1;
+            $arg1 .= $2;
+            my $macro=$2;
+            my $arguments=$3;
 
-	    if ($inline{$macro}) {
-		$paragraph .= "PO4A-INLINE:".$line.":PO4A-INLINE\n";
-		goto LINE;
-	    }
+            if ($inline{$macro}) {
+                $paragraph .= "PO4A-INLINE:".$line.":PO4A-INLINE\n";
+                goto LINE;
+            }
 
-	    # Split on spaces for arguments, but not spaces within double quotes
-	    my @args=();
-	    push @args,$arg1;
-	    if ($macro =~ /^(?:ta|TP|ie|if|de)$/) {
-		# The number of spaces may be critical for the 'ta' macro,
-		# and there is no need to split the arguments.
-		push @args, $arguments;
-	    } else {
-		push @args, splitargs($ref,$arguments);
-	    }
+            # Split on spaces for arguments, but not spaces within double quotes
+            my @args=();
+            push @args,$arg1;
+            if ($macro =~ /^(?:ta|TP|ie|if|de)$/) {
+                # The number of spaces may be critical for the 'ta' macro,
+                # and there is no need to split the arguments.
+                push @args, $arguments;
+            } else {
+                push @args, splitargs($ref,$arguments);
+            }
 
 
-	    if (length($paragraph)) {
-		do_paragraph($self,$paragraph,$wrapped_mode);
-		$paragraph="";
-		$wrapped_mode = $wrapped_mode eq 'NO' ? 'YES' : $wrapped_mode;
-	    }
+            if (length($paragraph)) {
+                do_paragraph($self,$paragraph,$wrapped_mode);
+                $paragraph="";
+                $wrapped_mode = $wrapped_mode eq 'NO' ? 'YES' : $wrapped_mode;
+            }
 
-	    # Special case: Don't change these lines
-	    #  .\"  => comments
-	    #  .\#  => comments
-	    #  ."   => comments
-	    #  .    => empty point on the line
-	    #  .tr abcd...
-	    #       => substitution like Perl's tr/ac/bd/ on output.
-	    if ($macro eq '\\"' || $macro eq '' || $macro eq 'tr' ||
-	        $macro eq '"'   || $macro eq '\\#') {
-		$self->pushline($self->r($line)."\n");
-		goto LINE;
-	    }
-	    # Special case:
-	    #  .nf => stop wrapped mode
-	    #  .fi => wrap again
-	    if ($no_wrap_begin{$macro} or $no_wrap_end{$macro}) {
-		if ($no_wrap_end{$macro}) {
-		    $wrapped_mode='YES';
-		} else {
-		    $wrapped_mode='MACRONO';
-		}
-		$self->pushline($self->r($line)."\n");
-		goto LINE;
-	    }
-	    
-	    # SH resets the wrapping (in addition to starting a section)
-	    if ($macro eq 'SH') {
-		$wrapped_mode='YES';
-	    }
-	    
-	    unshift @args,$self;
-	    # Apply macro
-	    $self->{type}=$macro;
+            # Special case: Don't change these lines
+            #  .\"  => comments
+            #  .\#  => comments
+            #  ."   => comments
+            #  .    => empty point on the line
+            #  .tr abcd...
+            #       => substitution like Perl's tr/ac/bd/ on output.
+            if ($macro eq '\\"' || $macro eq '' || $macro eq 'tr' ||
+                $macro eq '"'   || $macro eq '\\#') {
+                $self->pushline($self->r($line)."\n");
+                goto LINE;
+            }
+            # Special case:
+            #  .nf => stop wrapped mode
+            #  .fi => wrap again
+            if ($no_wrap_begin{$macro} or $no_wrap_end{$macro}) {
+                if ($no_wrap_end{$macro}) {
+                    $wrapped_mode='YES';
+                } else {
+                    $wrapped_mode='MACRONO';
+                }
+                $self->pushline($self->r($line)."\n");
+                goto LINE;
+            }
 
-	    if (defined ($macro{$macro})) {
-		&{$macro{$macro}}(@args);
-	    } else {
-		if (defined $unknown_macros) {
-		    &{$unknown_macros}(@args);
-		} else {
-		$self->pushline($self->r($line)."\n");
-		die wrap_ref_mod($ref, "po4a::man", dgettext("po4a",
-		    "Unknown macro '%s'. Remove it from the document, or refer to the Locale::Po4a::Man manpage to see how po4a can handle new macros."), $line);
-		}
-	    }
+            # SH resets the wrapping (in addition to starting a section)
+            if ($macro eq 'SH') {
+                $wrapped_mode='YES';
+            }
 
-	} elsif ($line =~ /^ +[^. ]/) {
-	    # (Lines containing only spaces are handled as empty lines)
-	    # Not a macro, but not a wrapped paragraph either
-	    $wrapped_mode = $wrapped_mode eq 'YES' ? 'NO' : $wrapped_mode;
-	    $paragraph .= $line."\n";
-	} elsif ($line =~ /^[^.].*/ && $line !~ /^ *$/) {
-	    # (Lines containing only spaces are handled latter as empty lines)
-	    if ($line =~ /^\\"/) {
-		# special case: the line is entirely a comment, keep the
-		# comment.
-		# NOTE: comment could also be found in the middle of a line.
-		# From info groff:
-		# Escape: \": Start a comment.  Everything to the end of the
-		# input line is ignored.
-		$self->pushline($self->r($line)."\n");
-		goto LINE;
-	    } elsif ($line =~ /^\\#/) {
-		# Special groff comment. Do not keep the new line
-		goto LINE;
-	    } else {
-		# Not a macro
-		# * first, try to handle some "output line continuation" (\c)
-		$paragraph =~ s/\\c *(($FONT_RE)?)\n?$/$1/s;
-		# * append the line to the current paragraph
-		$paragraph .= $line."\n";
-	    }
-	} else { #empty line, or line containing only spaces
-	    if (length($paragraph)) {
-	        do_paragraph($self,$paragraph,$wrapped_mode);
-	        $paragraph="";
-	    }
-	    $wrapped_mode = $wrapped_mode eq 'NO' ? 'YES' : $wrapped_mode;
-	    $self->pushline($line."\n");
-	}
+            unshift @args,$self;
+            # Apply macro
+            $self->{type}=$macro;
 
-	# finally, we did not reach the end of the paragraph.  The comments
-	# belong to the current paragraph.
-	push @comments, @next_comments;
-	@next_comments = ();
+            if (defined ($macro{$macro})) {
+                &{$macro{$macro}}(@args);
+            } else {
+                if (defined $unknown_macros) {
+                    &{$unknown_macros}(@args);
+                } else {
+                $self->pushline($self->r($line)."\n");
+                die wrap_ref_mod($ref, "po4a::man", dgettext("po4a",
+                    "Unknown macro '%s'. Remove it from the document, or refer to the Locale::Po4a::Man manpage to see how po4a can handle new macros."), $line);
+                }
+            }
 
-	# Reinit the loop
-	($line,$ref)=$self->shiftline();
-	undef $self->{type};
+        } elsif ($line =~ /^ +[^. ]/) {
+            # (Lines containing only spaces are handled as empty lines)
+            # Not a macro, but not a wrapped paragraph either
+            $wrapped_mode = $wrapped_mode eq 'YES' ? 'NO' : $wrapped_mode;
+            $paragraph .= $line."\n";
+        } elsif ($line =~ /^[^.].*/ && $line !~ /^ *$/) {
+            # (Lines containing only spaces are handled latter as empty lines)
+            if ($line =~ /^\\"/) {
+                # special case: the line is entirely a comment, keep the
+                # comment.
+                # NOTE: comment could also be found in the middle of a line.
+                # From info groff:
+                # Escape: \": Start a comment.  Everything to the end of the
+                # input line is ignored.
+                $self->pushline($self->r($line)."\n");
+                goto LINE;
+            } elsif ($line =~ /^\\#/) {
+                # Special groff comment. Do not keep the new line
+                goto LINE;
+            } else {
+                # Not a macro
+                # * first, try to handle some "output line continuation" (\c)
+                $paragraph =~ s/\\c *(($FONT_RE)?)\n?$/$1/s;
+                # * append the line to the current paragraph
+                $paragraph .= $line."\n";
+            }
+        } else { #empty line, or line containing only spaces
+            if (length($paragraph)) {
+                do_paragraph($self,$paragraph,$wrapped_mode);
+                $paragraph="";
+            }
+            $wrapped_mode = $wrapped_mode eq 'NO' ? 'YES' : $wrapped_mode;
+            $self->pushline($line."\n");
+        }
+
+        # finally, we did not reach the end of the paragraph.  The comments
+        # belong to the current paragraph.
+        push @comments, @next_comments;
+        @next_comments = ();
+
+        # Reinit the loop
+        ($line,$ref)=$self->shiftline();
+        undef $self->{type};
     }
 
     if (length($paragraph)) {
-	do_paragraph($self,$paragraph,$wrapped_mode);
-	$wrapped_mode = $wrapped_mode eq 'NO' ? 'YES' : $wrapped_mode;
-	$paragraph="";
+        do_paragraph($self,$paragraph,$wrapped_mode);
+        $wrapped_mode = $wrapped_mode eq 'NO' ? 'YES' : $wrapped_mode;
+        $paragraph="";
     }
 
     # flush the last comments
@@ -1403,7 +1405,7 @@ sub parse{
     @next_comments = @comments;
     @comments = ();
     for my $c (@next_comments) {
-	$self->pushline($self->r(".\\\"$c\n"));
+        $self->pushline($self->r("$$c[0]\\\"$$c[1]\n"));
     }
 
     # reinitialize the module
@@ -1755,9 +1757,9 @@ sub splitargs {
 sub translate_joined {
     my ($self,$macroname,$macroarg)=(shift,shift,join(" ",@_));
     #section# .S[HS] name
-    
+
     $self->pushmacro($macroname,
-		     $self->t($macroarg));
+                     $self->t($macroarg));
 }
 
 # For macro taking several arguments, having to be translated separately
@@ -1770,7 +1772,7 @@ sub translate_each {
 sub noarg {
     my $self = shift;
     warn "Macro $_[0] does not accept any argument\n"
-	if (defined ($_[1]));
+        if (defined ($_[1]));
     $self->pushmacro(@_);
 }
 
@@ -1794,11 +1796,11 @@ $macro{'TH'}= sub {
     $self->push_docheader();
 
     $self->pushmacro($th,
-		     $self->t($title),
-		     $section,
-		     $self->t($date),
-		     $self->t($source),
-		     $self->t($manual));
+                     $self->t($title),
+                     $section,
+                     $self->t($date),
+                     $self->t($source),
+                     $self->t($manual));
 };
 
 # .SS t    Subheading t (like .SH, but used for a subsection inside a section).
@@ -1828,14 +1830,14 @@ $macro{'SS'}=$macro{'SH'}=sub {
 $inline{'SM'}=1;
 
 # .SP n     Skip n lines (I think)
-$macro{'SP'}=\&untranslated;	
+$macro{'SP'}=\&untranslated;
 
 #Normal Paragraphs
 #  .LP      Same as .PP (begin a new paragraph).
 #  .P       Same as .PP (begin a new paragraph).
 #  .PP      Begin a new paragraph and reset prevailing indent.
 #Relative Margin Indent
-#  .RS i    Start relative margin indent - moves the left margin i to the right 
+#  .RS i    Start relative margin indent - moves the left margin i to the right
 #           As a result,  all  following  paragraph(s) will be indented until
 #           the corresponding .RE.
 #  .RE      End  relative  margin indent.
@@ -1860,9 +1862,9 @@ sub parse_tp_tq {
     ($l2,$ref2) = $self->shiftline();
     chomp($l2);
     while ($l2 =~ /^\.PD/) {
-	$self->pushline($self->r($l2)."\n");
-	($l2,$ref2) = $self->shiftline();
-	chomp($l2);
+        $self->pushline($self->r($l2)."\n");
+        ($l2,$ref2) = $self->shiftline();
+        chomp($l2);
     }
     if ($l2 =~/^([.'][\t ]*([^\t ]*))(?:([\t ]+)(.*)$|$)/) {
         if ($inline{$2}) {
@@ -1881,7 +1883,7 @@ sub parse_tp_tq {
             $self->SUPER::unshiftline($l2,$ref2);
         }
     } else {
-	$self->pushline($self->t($l2, "wrap" => 0)."\n");
+        $self->pushline($self->t($l2, "wrap" => 0)."\n");
     }
 }
 
@@ -1903,7 +1905,7 @@ $macro{'TP'}=sub {
 #      paragraph.
 $macro{'TQ'}=sub {
     warn "Macro $_[1] does not accept any argument\n"
-	if (defined ($_[2]));
+        if (defined ($_[2]));
 
     parse_tp_tq(@_);
 };
@@ -1930,20 +1932,20 @@ $macro{'HP'}=sub {
 #              designator) are reset to its default values.  To start an  indented
 #              paragraph  with  a particular indentation but without a designator,
 #              use `""' (two doublequotes) as the second argument.
-	
+
 # Note that the above is the groff_man(7) version, which of course differs radically
-# from man(7). In one case, the designator is optional and the nnn is not, and the 
+# from man(7). In one case, the designator is optional and the nnn is not, and the
 # contrary in the other. This implies that when sticking to groff_man(7), we should
-# mark an uniq argument as translatable. 
-	
+# mark an uniq argument as translatable.
+
 $macro{'IP'}=sub {
     my $self=shift;
     if (defined $_[2]) {
-	$self->pushmacro($_[0],$self->t($_[1]),$_[2]);
+        $self->pushmacro($_[0],$self->t($_[1]),$_[2]);
     } elsif (defined $_[1]) {
-	$self->pushmacro($_[0],$self->t($_[1]));
+        $self->pushmacro($_[0],$self->t($_[1]));
     } else {
-	$self->pushmacro(@_);
+        $self->pushmacro(@_);
     }
 
     # From info groff:
@@ -1959,19 +1961,15 @@ $macro{'IP'}=sub {
 #         There is an exception: if u is the special value ":", then no
 #         hypertext link of any kind will be generated until after the
 #         closing UE (this permits disabling hypertext links in
-#         phrases like LALR(1) when linking is not appropriate). 
+#         phrases like LALR(1) when linking is not appropriate).
 #  .UE    Ends the corresponding UR command; when generating HTML this
 #         should translate into </A>.
 #  .UN u  Creates a named hypertext location named u; do not include a
 #         corresponding UE  command.
 #         When generating HTML this should translate into the HTML command
 #         <A  NAME="u" id="u">&nbsp;</A>
-$macro{'UR'}=sub {
-    return untranslated(@_) 
-	if (defined($_[2]) && $_[2] eq ':');
-    return translate_joined(@_);
-};
-$macro{'UE'}=\&noarg;
+$inline{'UR'}=1;
+$inline{'UE'}=1;
 $macro{'UN'}=\&translate_joined;
 
 # Miscellaneous Macros
@@ -1989,7 +1987,7 @@ $macro{'IX'}=\&translate_each;
 ###
 ### groff macros
 ###
-# .br 
+# .br
 $macro{'br'}=\&noarg;
 # .bp N      Eject current page and begin new page.
 $macro{'bp'}=\&untranslated;
@@ -2131,17 +2129,17 @@ $macro{'ig'}=sub {
     $end='' if ($end =~ m/^\\\"/);
     my ($line,$ref)=$self->shiftline();
     while (defined($line)) {
-	$self->pushline($self->r($line));
-	last if ($line =~ /^\.$end\./);
-	($line,$ref)=$self->shiftline();
+        $self->pushline($self->r($line));
+        last if ($line =~ /^\.$end\./);
+        ($line,$ref)=$self->shiftline();
     }
 };
 
 
 # .lf N file  Set input line number to N and filename to file.
-$macro{'lf'}=\&untranslated; 
+$macro{'lf'}=\&untranslated;
 # .ll N       Set line length according to N
-$macro{'ll'}=\&untranslated; 
+$macro{'ll'}=\&untranslated;
 
 # .nh         disable hyphenation (see hy)
 $macro{'nh'}=\&untranslated;
@@ -2158,7 +2156,7 @@ $macro{'ps'}=\&untranslated;
 # .mso groff variant of .so (other search path)
 $macro{'so'}= $macro{'mso'} = sub {
     warn wrap_mod("po4a::man", dgettext("po4a",
-	"This page includes another file with '%s'. Do not forget to translate this file ('%s')."), $_[1], $_[2]);
+        "This page includes another file with '%s'. Do not forget to translate this file ('%s')."), $_[1], $_[2]);
     my $self = shift;
     $self->pushmacro(@_);
 };
@@ -2187,47 +2185,79 @@ $macro{'ta'}=sub {
 $macro{'ti'}=\&untranslated;
 
 
-### 
+###
 ### tbl macros
-### 
+###
 $macro{'TS'}=sub {
     my $self=shift;
     my ($in_headers,$buffer)=(1,"");
+    my ($in_textblock,$preline,$postline)=(0,"","");
     my ($line,$ref)=$self->shiftline();
-    
+
     # Push table start
     $self->pushmacro(@_);
     while (defined($line)) {
-	if ($line =~ /^\.TE/) {
-	    # Table end
-	    $self->pushline($self->r($line));
-	    return;
-	}
-	if ($in_headers) {
-	    if ($line =~ /\.$/) {
-		$in_headers = 0;
-	    }
-	    $self->pushline($self->r($line));
-	} elsif ($line =~ /\\$/) {
-	    # Lines are continued on \ at the end of line
-	    $buffer .= $line;
-	} else {
-	    $buffer .= $line;
-	    # Arguments to translate are separated by \t
-	    $self->pushline(join("\t",
-				 map { $self->translate($buffer,
-							$ref,
-							'tbl table') 
-				     } split (/\\t/,$line)));
-	    $buffer = "";
-	}
-	($line,$ref)=$self->shiftline();
+        if ($line =~ /^\.TE/) {
+            # Table end
+            $self->pushline($self->r($line));
+            return;
+        }
+        if ($in_headers) {
+            if ($line =~ /\.$/) {
+                $in_headers = 0;
+            }
+            $self->pushline($self->r($line));
+        } elsif ($in_textblock && $line =~ /^T}\s*/) { # end of text block
+            $in_textblock = 0;
+            $preline = $&; # save the `T}' marker to be output later
+            $line = $';    # save the remaing part of the line
+            $self->pushline($self->translate($buffer,
+                                             $ref,
+                                            'tbl table'));
+            $buffer = "";
+            next; # continue processing with the remaining part of the line
+        } elsif ($in_textblock && $line =~ /^[.']/) {
+            # TODO: properly handle macros inside text blocks, currently we mark them
+            # for translations just like the previous version did
+            $self->pushline($self->translate($buffer,
+                                             $ref,
+                                            'tbl table'));
+            $self->pushline($self->translate($line,
+                                             $ref,
+                                            'tbl table'));
+            $buffer = "";
+        } elsif ($line =~ /\\$/ || $in_textblock) {
+            # Lines are continued on \ at the end of line
+            $buffer .= $line;
+        } else {
+            if ($line =~ s/\s*T\{\s*$//) { # start of text block
+              $in_textblock = 1;
+              $postline = $&; # save the `T{' to be outputed below
+            } elsif ($buffer eq "" && $line ne ""){ # single line data
+              chomp $line; # drop eol char from the entry to be translated
+              $postline = "\n"; # and save the eol for output below
+            }
+
+            $buffer .= $line;
+            # Arguments to translate are separated by \t
+            $self->pushline($preline
+                            .join("\t",
+                                 map { $self->translate($_,
+                                                        $ref,
+                                                        'tbl table')
+                                     } split (/\t/,$buffer))
+                           .$postline);
+
+            $buffer = $preline = $postline = "";
+ 
+        }
+        ($line,$ref)=$self->shiftline();
     }
 };
 
 ###
 ### info groff
-### 
+###
 
 ## Builtin register, of course they do not need to be translated
 
@@ -2274,10 +2304,10 @@ $macro{'ce'}=$macro{'ul'}=$macro{'cu'}=sub {
 # All of these are not handled yet because the number of line may change
 # during the translation
             die wrap_mod("po4a::man", dgettext("po4a",
-		"This page uses the '%s' request with the number of lines in argument. This is not supported yet."), $_[0]);
+                "This page uses the '%s' request with the number of lines in argument. This is not supported yet."), $_[0]);
         }
     } else {
-	$self->pushmacro($_[0]);
+        $self->pushmacro($_[0]);
     }
 };
 
@@ -2289,7 +2319,7 @@ $macro{'ec'}=sub {
     my $self=shift;
     if (defined $_[1]) {
         die wrap_mod("po4a::man", dgettext("po4a",
-	    "This page uses the '%s' request. This request is only supported when no argument is provided."), $_[0]);
+            "This page uses the '%s' request. This request is only supported when no argument is provided."), $_[0]);
     } else {
         $self->pushmacro($_[0]);
     }
@@ -2299,8 +2329,8 @@ $macro{'ec'}=sub {
 ###
 ### BSD compatibility macros: .AT and .UC
 ### (define the version of Berkley used)
-### FIXME: the header ("3rd Berkeley Distribution" or such) declared 
-###        by this macro isn't translatable we may want to remove 
+### FIXME: the header ("3rd Berkeley Distribution" or such) declared
+###        by this macro isn't translatable we may want to remove
 ###        this from the generated manpage, and declare our own header
 ###
 $macro{'UC'}=$macro{'AT'}=\&untranslated;
@@ -2405,6 +2435,8 @@ sub define_mdoc_macros {
     $macro{'Ss'}=\&translate_mdoc;
     # .Pp   Paragraph Break.  Vertical space (one line).
     $macro{'Pp'}=\&noarg;
+    # .Lp   Same as .Pp
+    $macro{'Lp'}=\&noarg;
     # .D1   (D-one) Display-one Indent and display one text line.
     $macro{'D1'}=\&translate_mdoc;
     # .Dl   (D-ell) Display-one literal.
@@ -2425,6 +2457,8 @@ sub define_mdoc_macros {
     # FIXME: Maybe we could extract other modifiers
     #        as in .It Fl l Ar num
     $macro{'It'}=\&translate_mdoc;
+    # .Lk   html link
+    $macro{'Lk'}=\&untranslated;
 
     # Manual Domain Macros
     # ====================
@@ -2438,8 +2472,8 @@ sub define_mdoc_macros {
 
     # General Text Domain
     # ===================
-    foreach (qw(%A %B %C %D %J %N %O %P %R %T %V
-                Ac Ao Ap Aq At Bc Bf Bo Bq Bx Db Dc Do Dq Ec Ef Em Eo Fx No Ns
+    foreach (qw(%A %B %C %D %I %J %N %O %P %Q %R %T %U %V
+                Ac Ao Ap Aq At Bc Bf Bo Bq Brc Bro Brq Bx Db Dc Do Dq Ec Ef Em Eo Eq Fx No Ns
                 Pc Pf Po Pq Qc Ql Qo Qq Re Rs Rv Sc So Sq Sm Sx Sy Tn Ux Xc Xo)) {
         $inline{$_} = 1;
     }
@@ -2475,10 +2509,6 @@ sub define_mdoc_macros {
     $macro{'In'} = \&translate_mdoc;
     # NetBSD Macro
     $inline{'Nx'} = 1;
-    # Curly brackets
-    $inline{'Brq'} = 1;
-    # Corporate name
-    $inline{'%Q'} = 1;
     # Math symbol
     $inline{'Ms'} = 1;
     # Prints 'under development'
