@@ -44,7 +44,7 @@ areas where they were not expected like documentation.
 Locale::Po4a::Sgml is a module to help the translation of documentation in
 the SGML format into other [human] languages.
 
-This module uses B<nsgmls> to parse the SGML files. Make sure it is
+This module uses B<nsgmls>(1) to parse the SGML files. Make sure it is
 installed.
 Also make sure that the DTD of the SGML files are installed in the system.
 
@@ -147,7 +147,7 @@ nsgmls eats them, and I don't know how to restore them in the final
 document. To prevent that, I rewrite them to C<{PO4A-beg-foo}> and
 C<{PO4A-end}>.
 
-The problem with this is that the C<{PO4A-end}> and such I add are valid in
+The problem with this is that the C<{PO4A-end}> and such I add are invalid in
 the document (not in a E<lt>pE<gt> tag or so).
 
 Everything works well with nsgmls's output redirected that way, but it will
@@ -413,7 +413,7 @@ sub parse_file {
         $lvl=1;
         while ($lvl != 0) {
             # Eat comments in the prolog, since there may be some '>' or '<' in them.
-            if ($origfile =~ m/^.{$pos}?(<!--.*?-->)/s) {
+            if ($origfile =~ m/^.{$pos}(<!--.*?-->)/s) {
                 print "Found a comment in the prolog: $1\n" if ($debug{'generic'});
                 $pos += length($1);
                 # take care of the line numbers
@@ -672,9 +672,9 @@ sub parse_file {
             }
         }
     }
-    $prolog =~ s/<!--{PO4A-ent-beg-(.*?)}(.*?){PO4A-ent-end}-->/<!ENTITY % $1 SYSTEM "$2">/g;
+    $prolog =~ s/<!--\{PO4A-ent-beg-(.*?)\}(.*?)\{PO4A-ent-end\}-->/<!ENTITY % $1 SYSTEM "$2">/g;
     # Unprotect undefined inclusions, and die of them
-    $prolog =~ s/{PO4A-percent}/%/sg;
+    $prolog =~ s/\{PO4A-percent\}/%/sg;
     if ($prolog =~ /%([^;\s]*);/) {
         die wrap_mod("po4a::sgml",
                      dgettext("po4a",
